@@ -1,3 +1,7 @@
+// Package ad is responsible for the Active Directory connection to parse what to apply to each user/machine,
+// get the URL and permissions on what to fetch, downloads GPOs policy files and assets.
+//
+// It has a cache policy to avoid unnecessary downloads.
 package ad
 
 import (
@@ -16,16 +20,16 @@ import (
 	"sync"
 	"time"
 
-	"github.com/godbus/dbus/v5"
+	"github.com/ubuntu/adsys/internal/ad/backends"
 	adcommon "github.com/ubuntu/adsys/internal/ad/common"
 	"github.com/ubuntu/adsys/internal/ad/registry"
 	"github.com/ubuntu/adsys/internal/consts"
-	"github.com/ubuntu/adsys/internal/decorate"
 	log "github.com/ubuntu/adsys/internal/grpc/logstreamer"
 	"github.com/ubuntu/adsys/internal/i18n"
 	"github.com/ubuntu/adsys/internal/policies"
 	"github.com/ubuntu/adsys/internal/policies/entry"
 	"github.com/ubuntu/adsys/internal/smbsafe"
+	"github.com/ubuntu/decorate"
 	"golang.org/x/sync/errgroup"
 )
 
@@ -36,7 +40,14 @@ const (
 	// UserObject is a user representation in AD.
 	UserObject ObjectClass = "user"
 	// ComputerObject is a computer representation in AD.
-	ComputerObject = "computer"
+	ComputerObject ObjectClass = "computer"
+
+	// certAutoEnrollKey is the GPO entry that configures certificate autoenrollment.
+	certAutoEnrollKey string = "Software/Policies/Microsoft/Cryptography/AutoEnrollment/AEPolicy"
+
+	// policyServerPrefix is the GPO prefix containing keys that configure
+	// policy servers for certificate enrollment.
+	policyServersPrefix string = "Software/Policies/Microsoft/Cryptography/PolicyServers/"
 )
 
 type gpo downloadable
@@ -54,19 +65,13 @@ type downloadable struct {
 
 // AD structure to manage call concurrency.
 type AD struct {
-	isOffline bool
-
-	hostname            string
-	url                 string
-	defaultDomainSuffix string
+	hostname      string
+	configBackend backends.Backend
 
 	versionID        string
 	sysvolCacheDir   string
 	policiesCacheDir string
 	krb5CacheDir     string
-	sssCCName        string
-
-	sssdDbus dbus.BusObject
 
 	downloadables map[string]*downloadable
 	sync.RWMutex
@@ -77,13 +82,12 @@ type AD struct {
 }
 
 type options struct {
-	versionID           string
-	runDir              string
-	cacheDir            string
-	sssCacheDir         string
-	defaultDomainSuffix string
-	withoutKerberos     bool
-	gpoListCmd          []string
+	versionID string
+	runDir    string
+	cacheDir  string
+
+	withoutKerberos bool
+	gpoListCmd      []string
 }
 
 // Option reprents an optional function to change AD behavior.
@@ -105,29 +109,14 @@ func WithRunDir(runDir string) Option {
 	}
 }
 
-// WithSSSCacheDir specifies which cache directory to use for SSS.
-func WithSSSCacheDir(cacheDir string) Option {
-	return func(o *options) error {
-		o.sssCacheDir = cacheDir
-		return nil
-	}
-}
-
-// WithDefaultDomainSuffix specifies a default domain suffix we provide.
-func WithDefaultDomainSuffix(defaultDomainSuffix string) Option {
-	return func(o *options) error {
-		o.defaultDomainSuffix = defaultDomainSuffix
-		return nil
-	}
-}
-
 // AdsysGpoListCode is the embedded script which request
 // Samba to get our GPO list for the given object.
+//
 //go:embed adsys-gpolist
 var AdsysGpoListCode string
 
 // New returns an AD object to manage concurrency, with a local kr5 ticket from machine keytab.
-func New(ctx context.Context, url, domain string, bus *dbus.Conn, opts ...Option) (ad *AD, err error) {
+func New(ctx context.Context, configBackend backends.Backend, hostname string, opts ...Option) (ad *AD, err error) {
 	defer decorate.OnError(&err, i18n.G("can't create Active Directory object"))
 
 	versionID, err := adcommon.GetVersionID("/")
@@ -137,11 +126,10 @@ func New(ctx context.Context, url, domain string, bus *dbus.Conn, opts ...Option
 
 	// defaults
 	args := options{
-		runDir:      consts.DefaultRunDir,
-		cacheDir:    consts.DefaultCacheDir,
-		sssCacheDir: consts.DefaultSSSCacheDir,
-		gpoListCmd:  []string{"python3", "-c", AdsysGpoListCode},
-		versionID:   versionID,
+		runDir:     consts.DefaultRunDir,
+		cacheDir:   consts.DefaultCacheDir,
+		gpoListCmd: []string{"python3", "-c", AdsysGpoListCode},
+		versionID:  versionID,
 	}
 	// applied options
 	for _, o := range opts {
@@ -151,7 +139,7 @@ func New(ctx context.Context, url, domain string, bus *dbus.Conn, opts ...Option
 	}
 
 	krb5CacheDir := filepath.Join(args.runDir, "krb5cc")
-	if err := os.MkdirAll(krb5CacheDir, 0700); err != nil {
+	if err := os.MkdirAll(filepath.Join(krb5CacheDir, "tracking"), 0700); err != nil {
 		return nil, err
 	}
 	sysvolCacheDir := filepath.Join(args.cacheDir, "sysvol")
@@ -164,35 +152,23 @@ func New(ctx context.Context, url, domain string, bus *dbus.Conn, opts ...Option
 		return nil, err
 	}
 
-	hostname, err := os.Hostname()
-	if err != nil {
-		return nil, err
-	}
-	// for misconfigured machines where /proc/sys/kernel/hostname returns the fqdn and not only the machine name, strip it
-	hostname = strings.TrimSuffix(hostname, "."+domain)
-
-	// local machine sssd krb5 cache
-	sssCCName := filepath.Join(args.sssCacheDir, "ccache_"+strings.ToUpper(domain))
-
-	sssdDbus := bus.Object(consts.SSSDDbusRegisteredName,
-		dbus.ObjectPath(filepath.Join(consts.SSSDDbusBaseObjectPath, strings.ReplaceAll(domain, ".", "_2e"))))
-
-	if url != "" && !strings.HasPrefix(url, "ldap://") {
-		url = fmt.Sprintf("ldap://%s", url)
+	domain := configBackend.Domain()
+	serverFQDN, err := configBackend.ServerFQDN(ctx)
+	if err != nil && !errors.Is(err, backends.ErrNoActiveServer) {
+		return nil, fmt.Errorf(i18n.G("can't get current Server FQDN: %w"), err)
 	}
+	log.Debugf(ctx, "Backend is SSSD. AD domain: %q, server from configuration: %q", domain, serverFQDN)
 
 	return &AD{
-		hostname:            hostname,
-		url:                 url,
-		defaultDomainSuffix: args.defaultDomainSuffix,
-		versionID:           args.versionID,
-		sysvolCacheDir:      sysvolCacheDir,
-		policiesCacheDir:    policiesCacheDir,
-		krb5CacheDir:        krb5CacheDir,
-		sssCCName:           sssCCName,
-		sssdDbus:            sssdDbus,
-		downloadables:       make(map[string]*downloadable),
-		gpoListCmd:          args.gpoListCmd,
+		hostname:         hostname,
+		configBackend:    configBackend,
+		versionID:        args.versionID,
+		sysvolCacheDir:   sysvolCacheDir,
+		policiesCacheDir: policiesCacheDir,
+		krb5CacheDir:     krb5CacheDir,
+
+		downloadables: make(map[string]*downloadable),
+		gpoListCmd:    args.gpoListCmd,
 	}, nil
 }
 
@@ -212,29 +188,38 @@ func (ad *AD) GetPolicies(ctx context.Context, objectName string, objectClass Ob
 		return pols, fmt.Errorf(i18n.G("user name %q should be of the form %s@DOMAIN"), objectName, objectName)
 	}
 
-	krb5CCPath := filepath.Join(ad.krb5CacheDir, objectName)
 	if objectClass == ComputerObject && objectName != ad.hostname {
 		return pols, fmt.Errorf(i18n.G("requested a type computer of %q which isn't current host %q"), objectName, ad.hostname)
 	}
-	// Create a ccache symlink on first fetch for futur calls (on refresh for instance)
+
+	krb5CCPath := filepath.Join(ad.krb5CacheDir, objectName)
+	krb5CCSymlink := filepath.Join(ad.krb5CacheDir, "tracking", objectName)
+	// Create a ccache symlink on first fetch for future calls (on refresh for instance)
 	if userKrb5CCName != "" || objectClass == ComputerObject {
 		src := userKrb5CCName
 		// there is no env var for machine: get sss ccache
 		if objectClass == ComputerObject {
-			src = ad.sssCCName
+			src, err = ad.configBackend.HostKrb5CCName()
+			if err != nil {
+				return pols, err
+			}
 		}
-		if err := ad.ensureKrb5CCName(src, krb5CCPath); err != nil {
+
+		// Create a symlink to the ccache file
+		if err := ad.ensureKrb5CCSymlink(src, krb5CCSymlink); err != nil {
 			return pols, err
 		}
 	}
 
+	// Ensure we have an up-to-date copy of the ccache file
+	if err := ad.ensureKrb5CCCopy(krb5CCSymlink, krb5CCPath); err != nil {
+		return pols, err
+	}
+
 	var online bool
-	if err := ad.sssdDbus.Call(consts.SSSDDbusInterface+".IsOnline", 0).Store(&online); err != nil {
-		return pols, fmt.Errorf(i18n.G("failed to retrieve offline state from SSSD: %v"), err)
+	if online, err = ad.configBackend.IsOnline(); err != nil {
+		return pols, err
 	}
-	ad.Lock()
-	ad.isOffline = !online
-	ad.Unlock()
 
 	// If sssd returns that we are offline, returns the cache list of GPOs if present
 	if !online {
@@ -247,30 +232,15 @@ func (ad *AD) GetPolicies(ctx context.Context, objectName string, objectClass Ob
 		return cachedPolicies, nil
 	}
 
-	// We need an AD LDAP url to connect to
-	adServerURL, _ := ad.GetStatus()
-	if adServerURL == "" {
-		log.Debug(ctx, "Triggering autodiscovery of AD server triggered because sssd.conf or manual url not provided")
-		// Try to update from SSSD the current active AD server
-		msg := i18n.G("error while trying to look up AD server address on SSSD")
-		err := ad.sssdDbus.Call(consts.SSSDDbusInterface+".ActiveServer", 0, "AD").Store(&adServerURL)
-		if err != nil {
-			return pols, fmt.Errorf(i18n.G("%s: %v"), msg, err)
-		}
-		if adServerURL == "" {
-			return pols, fmt.Errorf(i18n.G("%s: no active server found"), msg)
-		}
-		if !strings.HasPrefix(adServerURL, "ldap://") {
-			adServerURL = fmt.Sprintf("ldap://%s", adServerURL)
-		}
-		ad.Lock()
-		ad.url = adServerURL
-		ad.Unlock()
+	// We need an AD DC to connect to
+	adServerFQDN, err := ad.configBackend.ServerFQDN(ctx)
+	if err != nil {
+		return policies.Policies{}, fmt.Errorf(i18n.G("can't get current Server FQDN: %w"), err)
 	}
 
 	// Otherwise, try fetching the GPO list from LDAP
 	args := append([]string{}, ad.gpoListCmd...) // Copy gpoListCmd to prevent data race
-	scriptArgs := []string{"--objectclass", string(objectClass), adServerURL, objectName}
+	scriptArgs := []string{"--objectclass", string(objectClass), adServerFQDN, objectName}
 	cmdArgs := append(args, scriptArgs...)
 	cmdCtx, cancel := context.WithTimeout(ctx, time.Second*10)
 	defer cancel()
@@ -374,39 +344,51 @@ func (ad *AD) GetPolicies(ctx context.Context, objectName string, objectClass Ob
 	return policies.New(ctx, gposRules, assetsDbPath)
 }
 
-// ListActiveUsers return the list of active users on the system.
-func (ad *AD) ListActiveUsers(ctx context.Context) (users []string, err error) {
+// ListUsers returns the list of users on the system based on their cached policy information.
+// If active is true, the list of users is retrieved from the cached Kerberos ticket information.
+func (ad *AD) ListUsers(ctx context.Context, active bool) (users []string, err error) {
 	defer decorate.OnError(&err, i18n.G("can't list users from cache"))
 
-	log.Debug(ctx, "ListActiveUsers")
+	log.Debug(ctx, "ListUsers")
 
 	ad.Lock()
 	defer ad.Unlock()
 
-	files, err := os.ReadDir(ad.krb5CacheDir)
+	cacheDir := ad.policiesCacheDir
+	if active {
+		cacheDir = filepath.Join(ad.krb5CacheDir, "tracking")
+	}
+
+	entries, err := os.ReadDir(cacheDir)
 	if err != nil {
 		return users, fmt.Errorf(i18n.G("failed to read cache directory: %v"), err)
 	}
 
-	for _, file := range files {
-		if !strings.Contains(file.Name(), "@") {
+	for _, entry := range entries {
+		if !strings.Contains(entry.Name(), "@") {
 			continue
 		}
-		users = append(users, file.Name())
+
+		// Silently skip over dangling symlinks
+		if active {
+			if _, err := os.Stat(filepath.Join(cacheDir, entry.Name())); err != nil && errors.Is(err, fs.ErrNotExist) {
+				continue
+			}
+		}
+		users = append(users, entry.Name())
 	}
 	return users, nil
 }
 
-// ensureKrb5CCName manages user ccname symlinks.
-// It handles concurrent calls, and only recreate the symlink if we want to point to
-// a new destination.
-func (ad *AD) ensureKrb5CCName(srcKrb5CCName, dstKrb5CCName string) (err error) {
-	defer decorate.OnError(&err, i18n.G("can't create symlink for caching"))
-
+// ensureKrb5CCSymlink manages user ccname ticket symlinks.
+// It handles concurrent calls, and works by creating a symlink to the
+// actual ticket for tracking purposes.
+// It only recreates the symlink if we want to point to a new destination.
+func (ad *AD) ensureKrb5CCSymlink(srcKrb5CCName, dstKrb5CCName string) error {
 	ad.Lock()
 	defer ad.Unlock()
 
-	srcKrb5CCName, err = filepath.Abs(srcKrb5CCName)
+	srcKrb5CCName, err := filepath.Abs(srcKrb5CCName)
 	if err != nil {
 		return fmt.Errorf(i18n.G("can't get absolute path of ccname to symlink to: %v"), err)
 	}
@@ -423,12 +405,69 @@ func (ad *AD) ensureKrb5CCName(srcKrb5CCName, dstKrb5CCName string) (err error)
 		}
 	}
 
+	if err := os.MkdirAll(filepath.Dir(dstKrb5CCName), 0700); err != nil {
+		return fmt.Errorf(i18n.G("failed to create parent directory for symlink: %w"), err)
+	}
+
 	if err := os.Symlink(srcKrb5CCName, dstKrb5CCName); err != nil {
 		return err
 	}
 	return nil
 }
 
+// ensureKrb5CCCopy checks if the cached krb5cc ticket is up to date and updates
+// it if not.
+// The file ownership is changed to the calling user (root) in order to satisfy
+// the Heimdal implementation of Kerberos.
+// To track modifications to the krb5cc file we look at the mtime of the
+// original ticket and keep it up to date with
+// the copy.
+func (ad *AD) ensureKrb5CCCopy(krb5CCSymlink, krb5CCCopyName string) error {
+	ad.Lock()
+	defer ad.Unlock()
+
+	krb5CCSrc, err := os.Readlink(krb5CCSymlink)
+	if err != nil {
+		return fmt.Errorf(i18n.G("failed to read krb5cc symlink: %w"), err)
+	}
+
+	if copyStat, err := os.Lstat(krb5CCCopyName); err == nil && copyStat.Mode()&os.ModeSymlink == 0 {
+		// We already have a copy of the ticket, let's check if we need to update it
+		srcStat, err := os.Stat(krb5CCSrc)
+		if err != nil {
+			return fmt.Errorf(i18n.G("failed to stat source ticket: %w"), err)
+		}
+
+		// The source ticket is not newer than the destination one, no need to update
+		if !srcStat.ModTime().After(copyStat.ModTime()) {
+			return nil
+		}
+	}
+
+	// The ticket is either not present or outdated, let's update it
+	// Copy the ticket
+	if err := safeCopyFile(krb5CCSrc, krb5CCCopyName, 0600); err != nil {
+		return err
+	}
+
+	return nil
+}
+
+// safeCopyFile copies a file from src to dst, using the specified mode.
+// It first writes to a temporary file in the same directory as dst, then
+// renames it to dst, ensuring the write is atomic.
+func safeCopyFile(src, dst string, mode os.FileMode) error {
+	content, err := os.ReadFile(src)
+	if err != nil {
+		return fmt.Errorf(i18n.G("failed to read source file: %w"), err)
+	}
+	if err := os.WriteFile(dst+".new", content, mode); err != nil {
+		return err
+	}
+
+	return os.Rename(dst+".new", dst)
+}
+
 func (ad *AD) parseGPOs(ctx context.Context, gpos []gpo, objectClass ObjectClass) (r []policies.GPO, err error) {
 	keyFilterPrefix := fmt.Sprintf("%s/%s/", adcommon.KeyPrefix, consts.DistroID)
 
@@ -490,6 +529,16 @@ func (ad *AD) parseGPOs(ctx context.Context, gpos []gpo, objectClass ObjectClass
 			var currentKey string
 			var overrideEnabled bool
 			for _, pol := range pols {
+				// Rewrite the certificate autoenrollment key so we can easily
+				// use it in the policy manager
+				if pol.Key == certAutoEnrollKey {
+					pol.Key = fmt.Sprintf("%scertificate/autoenroll/all", keyFilterPrefix)
+				}
+
+				if strings.HasPrefix(pol.Key, policyServersPrefix) {
+					pol.Key = fmt.Sprintf("%scertificate/%s/all", keyFilterPrefix, pol.Key)
+				}
+
 				// Only consider supported policies for this distro
 				if !strings.HasPrefix(pol.Key, keyFilterPrefix) {
 					continue
@@ -542,14 +591,31 @@ func (ad *AD) parseGPOs(ctx context.Context, gpos []gpo, objectClass ObjectClass
 	return r, nil
 }
 
-// GetStatus returns dynamic part of our AD instance like offline state and active server for AD ldap.
-func (ad *AD) GetStatus() (adServerURL string, isOffline bool) {
-	ad.RLock()
-	defer ad.RUnlock()
-	return ad.url, ad.isOffline
+// GetInfo returns all information from the selected backend: static and dynamic part.
+func (ad *AD) GetInfo(ctx context.Context) (msg string) {
+	// static part
+	config := ad.configBackend.Config()
+
+	// dynamic info
+	var online string
+	if isOnline, err := ad.configBackend.IsOnline(); err != nil {
+		log.Warning(ctx, err)
+		online = fmt.Sprint(i18n.G("**Can't check if we have an active connection**\n"))
+	} else if !isOnline {
+		online = fmt.Sprint(i18n.G("**Offline mode** using cached policies\n"))
+	}
+	domain := ad.configBackend.Domain()
+	server, err := ad.configBackend.ServerFQDN(ctx)
+	if err != nil {
+		server = "Unknown"
+	}
+
+	return fmt.Sprintf(i18n.G("%s\n%sDomain: %s\nServer FQDN: %s"), config, online, domain, server)
 }
 
-// NormalizeTargetName transforms and lowercases User or DOMAIN\User to user@domain.
+// NormalizeTargetName transforms the specified target to values adsys knows.
+// User: transforms and lowercases User or DOMAIN\User to user@domain.
+// Computer: strips the FQDN part, if it exists, and lowercases it.
 // If no domain is provided, we rely on having a default domain policy.
 func (ad *AD) NormalizeTargetName(ctx context.Context, target string, objectClass ObjectClass) (string, error) {
 	log.Debugf(ctx, "NormalizeTargetName for %q, type %q", target, objectClass)
@@ -560,6 +626,8 @@ func (ad *AD) NormalizeTargetName(ctx context.Context, target string, objectClas
 	target = strings.ToLower(target)
 
 	if objectClass == ComputerObject {
+		// For misconfigured machines where /proc/sys/kernel/hostname returns the fqdn and not only the machine name, strip it
+		target, _, _ = strings.Cut(target, ".")
 		return target, nil
 	}
 	// If we don’t know if this is a computer, try to ensure first this is not our hostname
@@ -582,14 +650,19 @@ func (ad *AD) NormalizeTargetName(ctx context.Context, target string, objectClas
 	default:
 		return "", fmt.Errorf(i18n.G(`only one \ is permitted in domain\username. Got: %s`), target)
 	}
-	if domainSuffix == "" && ad.defaultDomainSuffix == "" {
+	if domainSuffix == "" && ad.configBackend.DefaultDomainSuffix() == "" {
 		return "", fmt.Errorf(i18n.G(`no domain provided for user %q and no default domain in sssd.conf`), target)
 	}
 	if domainSuffix == "" {
-		domainSuffix = ad.defaultDomainSuffix
+		domainSuffix = ad.configBackend.DefaultDomainSuffix()
 	}
 
 	target = fmt.Sprintf("%s@%s", baseUser, domainSuffix)
 	log.Debugf(ctx, "Target name normalized to %q", target)
 	return target, nil
 }
+
+// Hostname returns the normalized hostname of the current client.
+func (ad *AD) Hostname() string {
+	return ad.hostname
+}
